SLiCAPconfigure.py — SLiCAP 4.0.7 documentation

# SLiCAPconfigure.py

SLiCAP scripts for configuration management.

1. Main configuration is stored in ~/SLiCAP/SLiCAP.ini

2. Project configuration is stored in <project folder>/SLiCAP.ini

Configuration settings are imported as global (ini.<setting>)

dump(section='all')

  Prints the global SLiCAP settings.

  Parameters:

    sections – “all”, or name of section to be printed: - VERSION - INSTALL - COMMANDS - PROJECT - PATHS - HTML - DSIPLAY - MATH - PLOT - BALANCING

  Return None:

  Rtype NoneType:

  Example:

      >>> import SLiCAP as sl
      >>> sl.ini.dump()